#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Print 'Hello world' to the terminal.

This is a simple test script using a hashbang line
and a PEP263 encoding line.
We use ordinary quotes in this test.
"""

print('Hello world')



"""Example of black and magic commas."""

vegetables = {
    "carrot",
    "parsnip",
    "potato",
    "swede",
    "leak",
    "aubergine",
    "tomato",
    "peas",
    "beans",
}

# This set would easily fit on one line, but a trailing comma
# after the final entry tells black (by default) to leave this
# with one entry per line:
yucky = {
    "aubergine",
    "squid",
    "snails",
}

print("I dislike these vegetables: %s." % ", ".join(vegetables.intersection(yucky)))
